
%OPTIONS
isMale=1; % male or female speaker data
n=7; % number of articulatory coordinates 
nPhone = 51; % number of phones
thetaC = 1.7 % critical threshold
isSave=0; % option fo saving results 
isDisp=1; % display results on screen

% load grand mean M, variance Sigma, sample size N, correlation matrix R
% hone mean muPhi, variance sigmaPhi, samplesize Nphi, correlation
% matrix Rphi (from make2Dstats.m)
if(isMale)
    load ./2dstats_m.mat
else
    load ./2dstats_f.mat    
end

phn_label = textread('./newHmmList','%s');

         
for phi =1:51
    %Model initialisation
    display(sprintf('processing phone %d.....',phi));
    
    k=1; %Ideally k=0, but matlab doesnt support it
    m(:,:,k) = M;
    S(:,:,:,k) = Sigma;
    Nu(:,k) = N*(ones(1,14));
    C{k} = [];
    while(k<=n+1)
        % computation of identification divergence
        for i = 1:n
            J(i,k) =  computeIdiv_2d(S(:,:,i,k), sigmaPhi(:,:,i,phi), m(:,i,k), muPhi(:,i,phi),Nu(i,k),Nphi(phi));
        end
        
        % articulator with maximum divergence 
        [val j] = max(J(:,k));
        
        %C-step
        if(J(j,k)>thetaC)
           
            k=k+1;
            % load previous level information
            m(:,:,k) = m(:,:,k-1);
            S(:,:,:,k) = S(:,:,:,k-1);
            Nu(:,k) = Nu(:,k-1);
        
            %critical update step
            C{k} = [C{k-1},j];
        
            m(:,j,k) = muPhi(:,j,phi);
            S(:,:,j,k) = sigmaPhi(:,:, j,phi);
            Nu(j,k) = Nphi(phi);
            
            %dependent update step
            [m(:,:,k), S(:,:,:,k), Nu(:,k)] = updateDep_2d(m(:,:,k), S(:,:,:,k), Nu(:,k), M, Sigma, muPhi(:,:,phi), sigmaPhi(:,:,:,phi), Nphi(phi),C{k}, R, Rphi{phi});
        else
            
            % Final model statistics for phone phi after identification of
            % all possible critical articulators
            hatC{phi} = C{k};
            K(phi) = k-1; % since we started from k=1 instead of k=0
            hatm(:,:,phi) = m(:,:,k);
            hatS(:,:,:,phi) = S(:,:,:,k);
                       
            k = 100;% exit from loop
        end
    end
end

% display results on screen
if(isDisp)
    disp2Dres
end

if(isSave)
    if(isMale)
        save ./2Dres_m.mat hatC K hatm hatS thetaC
    else
        save ./2Dres_f.mat hatC K hatm hatS thetaC
    end
end


        
