%function for updating the distribution of dependent articulator
%distributions 
% Input: m1 - model mean , s1 - model variance, n1- sample size of model ,
%        M- grand mean, Sigma- grand variance, R- grand correlation matrix
%        muPhi - Phone mean, sigmaPhi - phone variance , Nphi - phone
%        sample size, Rphi - phone correlation matrix
%        C- critical articulator list 
% Output: m1 - model mean, s1 - model variance , n1 - model sample size
% after the update

function [m1, s1, n1]= updateDep_1d(m1,s1,n1,M,Sigma, muPhi, sigmaPhi,Nphi, C, R, Rphi)
n=14;
Ncrit= length(C);
M_crit=[];
thetaD=0.1;
Sigma_crit=zeros(Ncrit, Ncrit);
muPhi_crit=[];
sigmaPhi_crit=zeros(Ncrit,Ncrit);

% Collating critical mean and covariances
  for j = C
      M_crit = [M_crit; M(j)];
      muPhi_crit =[muPhi_crit; muPhi(j)];
      
 end
  
  for i = 1:Ncrit
      for j = 1:Ncrit
          if(i==j)
              Sigma_crit(i,j) = Sigma(C(i));
              sigmaPhi_crit(i,j) = sigmaPhi(C(i));
          else
              Sigma_crit(i,j) = R(C(i),C(j))*sqrt(Sigma(C(i))*Sigma(C(j)));
              sigmaPhi_crit(i,j) = Rphi(C(i),C(j))*sqrt(sigmaPhi(C(i))*sigmaPhi(C(j)));
          end
      end
  end
 
  % computing identification divergence for D-step
    
   for i = 1:n
      J(i)=computeIdiv_1d(s1(i), sigmaPhi(i), m1(i), muPhi(i),n1(i),Nphi);
   end
  
   % Dependent update
   for i = 1:n  
      if(J(i)>thetaD)
          M_dep  = M(i);
          Sigma_dep  = Sigma(i); 
          Sigma_bet  = [R(C,i)'.* sqrt(Sigma(C)*Sigma(i))];
          n1(i) = Nphi;
          
          m1(i) = M_dep + Sigma_bet * inv(Sigma_crit) * (muPhi_crit - M_crit);
          s1(i) =  Sigma_dep +  Sigma_bet *  inv(Sigma_crit) * (sigmaPhi_crit -  Sigma_crit) * inv(Sigma_crit) * Sigma_bet';
      end
  end
          