%function for updating the distribution of dependent articulator
%distributions 
% Input: m1 - model mean , s1 - model variance, n1- sample size of model ,
%        M- grand mean, Sigma- grand variance, R- grand correlation matrix
%        muPhi - Phone mean, sigmaPhi - phone variance , Nphi - phone
%        sample size, Rphi - phone correlation matrix
%        C- critical articulator list 
% Output: m1 - model mean, s1 - model variance , n1 - model sample size
% after the update

function [m1, s1, n1]= updateDep_2d(m1,s1,n1,M,Sigma, muPhi, sigmaPhi,Nphi, C, R, Rphi)
n=7;
Ncrit= length(C);
M_crit=[];
thetaD=0.1;
Sigma_crit=[];
muPhi_crit=[];
sigmaPhi_crit=[];

% Collating critical mean and covariances
  for j = C
      M_crit = [M_crit; M(:,j)];
      muPhi_crit =[muPhi_crit; muPhi(:,j)];
      
 end
  
for i = C
    temp=[];
    for j =C
        if(i==j)
            temp = [temp,Sigma(:,:,i)];
        else
            temp = [temp,R(:,:,i,j).*[sqrt(Sigma(1,1,i)*Sigma(1,1,j)), sqrt(Sigma(1,1,i)*Sigma(2,2,j));....
                                     sqrt(Sigma(2,2,i)*Sigma(1,1,j)), sqrt(Sigma(2,2,i)*Sigma(2,2,j))]];
        end
    end
    Sigma_crit = [Sigma_crit; temp];
end

  
for i = C
    temp=[];
    for j =C
        if(i==j)
            temp = [temp,sigmaPhi(:,:,i)];
        else
            temp = [temp,Rphi(:,:,i,j).*[sqrt(sigmaPhi(1,1,i)*sigmaPhi(1,1,j)), sqrt(sigmaPhi(1,1,i)*sigmaPhi(2,2,j));....
                                     sqrt(sigmaPhi(2,2,i)*sigmaPhi(1,1,j)), sqrt(sigmaPhi(2,2,i)*sigmaPhi(2,2,j))]];
        end
    end
    sigmaPhi_crit = [sigmaPhi_crit; temp];
end                               

  % computing identification divergence for D-step    
   for i = 1:n
      J(i)=computeIdiv_2d(s1(:,:,i), sigmaPhi(:,:,i), m1(:,i), muPhi(:,i),n1(i),Nphi);
   end
  
   % Dependent update
   for i = 1:n  
      if(J(i)>thetaD)
          M_dep  = M(:,i);
          Sigma_dep  = Sigma(:,:,i); 
          
           %covariance between critical and dependent
           Sigma_bet = [];
           for j = C
               Sigma_bet = [Sigma_bet, R(:,:,i,j).*[sqrt(Sigma(1,1,i)*Sigma(1,1,j)), sqrt(Sigma(1,1,i)*Sigma(2,2,j));....
                                     sqrt(Sigma(2,2,i)*Sigma(1,1,j)), sqrt(Sigma(2,2,i)*Sigma(2,2,j))]];
           end
           n1(i) = Nphi;
          
          m1(:,i) = M_dep + Sigma_bet * inv(Sigma_crit) * (muPhi_crit - M_crit);
          s1(:,:,i) =  Sigma_dep +  Sigma_bet *  inv(Sigma_crit) * (sigmaPhi_crit -  Sigma_crit) * inv(Sigma_crit) * Sigma_bet';
      end
  end
          